#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# ----------------------------------------------------------------------------
# Created By  : Tof
# Created Date: 23/01/2024
# version ='9'
# ---------------------------------------------------------------------------
""" Converti les fichier barrières cl10 d'adrena en fichier .qbar pour qtVlm	"""
# ---------------------------------------------------------------------------
import json
import os
import tkinter as tk
from tkinter import filedialog, messagebox

def process_input_file(input_filename, output_filename, color, name, remove_first_point):
    with open(input_filename, 'r', encoding='latin-1') as infile:
        lines = infile.readlines()

    nbpolygone = 0
    
    # Extraire le nom du fichier sans extension
    base_filename = os.path.splitext(os.path.basename(input_filename))[0]
    print("\ntraitement de : " + base_filename)

    
    output_data = {
        "color": color,
        "name": base_filename,
        "points": []
    }

    for line in lines:
        if line.startswith("S;") or line.startswith("L;") or line.startswith("R;"):
            parts = line.strip().split(';')
            nbpolygone = nbpolygone + 1
            nbptsorigine = parts[20]
#            print("nombre de points dans le fichier d'origine: " + nbptsorigine)
            
            # Supprimer le premier point si l'option est activée
            if remove_first_point:
                start_index = 23  # Supprime le premier point
                nbpts = int(nbptsorigine) - 1
                end_index = start_index + int(nbpts) * 2
                
            else:
                start_index = 21  # Conserver le premier point
                end_index = start_index + int(nbptsorigine) * 2# -2

#            print("Polygone N°" + str(nbpolygone) + "   nombre de points : " + nbptsorigine + "   conservés : " + str(nbpts))
                
#            print("start_index : " + str(start_index))
#            print("end_index : " + str(end_index))

            pairs = parts[start_index:end_index]

            # Formater correctement le champ "points"
            processed_pairs = []
            for i in range(0, len(pairs), 2):
                pair = (float(pairs[i]), float(pairs[i + 1]))
                reversed_pair = (pair[1], pair[0])
                multiplied_pair = tuple(map(lambda x: x * 1000, reversed_pair))
                processed_pairs.append(f'{multiplied_pair[0]:.3f}/{multiplied_pair[1]:.3f}')

            # Ajouter les données au résultat final
            output_data["points"].append(['', '1', color, ';'.join(processed_pairs)])
            

    # Écrire le résultat dans le fichier de sortie
    output_filename = output_filename if output_filename.endswith('.qbar') else output_filename + '.qbar'
    with open(output_filename, 'w') as outfile:
        json.dump(output_data, outfile, separators=(',', ':'), indent=None)
    
    if nbpolygone > 1 :    
        print(str(nbpolygone) + " polygones traités")
    else:
        print(str(nbpolygone) + " polygone traité")
        
# Interface graphique pour choisir les fichiers
root = tk.Tk()
root.withdraw()  # Masquer la fenêtre principale

file_paths = filedialog.askopenfilenames(filetypes=[("Fichiers CL10", "*.cl10")])

# Demandez si l'utilisateur veut supprimer le premier point
answer = messagebox.askyesno("Suppression du premier point ?", "Le premier point semble être souvent le milieu du polygone ou de la ligne. Il déforme les polygones. Voulez-vous supprimer ce premier point ? ")


if file_paths:
#    print("Liste fichiers à traiter :")
#    for file_path in file_paths:
#        print(file_path)
#        print(os.path.splitext(file_path)[0])
#        print(/n)    
    nbfile = 0
    
    for file_path in file_paths:
        # Obtenez le nom du fichier de sortie
        output_filename = os.path.splitext(file_path)[0]
#        print(output_filename)

        # Obtenez la couleur et le nom à partir du début du fichier
        color, name = "#ff8880", "test"  # Vous pouvez ajuster ces valeurs selon vos besoins
        

        # Traitez tous les fichiers d'entrée et enregistrez le fichier de sortie
        process_input_file(file_path, output_filename, color, name, remove_first_point=answer)

        print(f"Résultat dans {output_filename}.qbar\n")
        nbfile = nbfile + 1
    if nbfile > 1 :
        print(str(nbfile) + " fichiers traités\n")
       
else:
    print("Aucun fichier sélectionné.")

